@@ -1,6 +1,7 @@
 import urllib.parse
 
 import httpx
+from pydantic import parse_obj_as
 
 from what_to_eat.models.location import Location
 
@@ -10,7 +11,7 @@ class LocationError(Exception):
         super().__init__("Error when trying to get location")
 
 
-def get(address: str) -> Location:
+def _get(address: str) -> Location:
     address = urllib.parse.quote(address)
     response = httpx.get(f"https://nominatim.openstreetmap.org/search/{address}?format=json")
 
@@ -18,3 +19,7 @@ def get(address: str) -> Location:
         raise LocationError()
 
     return Location.parse_obj(response.json()[0])
+
+
+def get(address: str) -> Location:
+    return parse_obj_as(Location, _get(address))
