@@ -7,6 +7,7 @@ from pydantic import parse_obj_as
 
 from what_to_eat.models.location import Location
 from what_to_eat.models.wolt import Item, Restaurant, Section
+from what_to_eat.utils import cache
 
 consumer_wolt_api_url: Final[str] = "https://consumer-api.wolt.com/v1/pages/front"
 restaurant_wolt_api_url: Final[str] = "https://restaurant-api.wolt.com/v3/venues/"
@@ -17,7 +18,8 @@ class WoltApiError(Exception):
         super().__init__("[Wolt] Error when trying to get response from wolt api")
 
 
-def sections(location: Location) -> list[Section]:
+@cache.use
+def _sections(location: Location) -> list[Section]:
     params = urllib.parse.urlencode(
         {
             "lat": location.lat,
@@ -37,11 +39,12 @@ def sections(location: Location) -> list[Section]:
     return parse_obj_as(list[Section], response.json()["sections"])
 
 
-def restaurant(item: Item) -> Restaurant:
+@cache.use
+def _restaurant(venue_id: str) -> Restaurant:
     headers = {
         "app-language": "en",
     }
-    response = httpx.get(restaurant_wolt_api_url + item.link.target, headers=headers)
+    response = httpx.get(restaurant_wolt_api_url + venue_id, headers=headers)
 
     if not response.is_success:
         raise WoltApiError()
@@ -49,4 +52,9 @@ def restaurant(item: Item) -> Restaurant:
 
 
 def items(location: Location) -> list[Item]:
-    return list({item for item in itertools.chain.from_iterable(s.items for s in sections(location)) if item.venue})
+    sections = parse_obj_as(list[Section], _sections(location))
+    return list({item for item in itertools.chain.from_iterable(s.items for s in sections) if item.venue})
+
+
+def restaurant(item: Item) -> Restaurant:
+    return parse_obj_as(Restaurant, _restaurant(item.link.target))
